@@ -524,14 +524,19 @@ static int bget_swab = 0;
 /* See op.c:Perl_newSTATEOP. Test 21 */
 # if (PERL_VERSION < 13) || ((PERL_VERSION == 13) && (PERL_SUBVERSION < 5))
 #  if defined(_WIN32) || (defined(__CYGWIN__) && (__GNUC__ > 3)) || defined(AIX)
-#   define BSET_cop_label(cop, arg)      /* XXX not exported */
+#   define BSET_cop_label(cop, arg)      /* Unlucky. Not exported with 5.12 and 5.14 */
+#   error "store_cop_label is not part of the public API for your perl. Try a perl <5.12 or >5.15"
 #  else
 #   define BSET_cop_label(cop, arg)	(cop)->cop_hints_hash = \
         Perl_store_cop_label(aTHX_ (cop)->cop_hints_hash, arg)
 #  endif
-# else
+# else /* officially added with 5.15.1 aebc0cbee */
+#  if  (PERL_VERSION > 15) || ((PERL_VERSION == 15) && (PERL_SUBVERSION > 0))
+#    define BSET_cop_label(cop, arg)	Perl_cop_store_label(aTHX_ (cop), arg, strlen(arg), 0)
+#  else
 /* changed with 5.13.4-5 a77ac40c5b8 */
-#  define BSET_cop_label(cop, arg)	Perl_store_cop_label(aTHX_ (cop), arg, strlen(arg), 0)
+#    define BSET_cop_label(cop, arg)	Perl_store_cop_label(aTHX_ (cop), arg, strlen(arg), 0)
+#  endif
 # endif
 #endif
 
