@@ -688,6 +688,12 @@ sub ctest {
                 ok (undef);
             }
 	} else {
+	    #crosscheck uncompiled
+	    my $out1 = `$runperl $name.pl`;
+            unless ($out1 =~ /$expected/) {
+                ok(1, "skip also fails uncompiled");
+                return;
+            }
 	    ok (undef);
 	}
     }
@@ -733,14 +739,19 @@ sub todo_tests_default {
     my $DEBUGGING = ($Config{ccflags} =~ m/-DDEBUGGING/);
     my $ITHREADS  = ($Config{useithreads});
 
-    my @todo  = (41..43,46,50); # 8,14-16 fail on 5.00505 (max 20 then)
+    my @todo  = (41..43,46); # 8,14-16 fail on 5.00505 (max 20 then)
     push @todo, (103)  if $] < 5.007 or $] >= 5.010;
     #push @todo, (29)   if $] >= 5.010 and !$DEBUGGING;
     #push @todo, (29)   if $] >= 5.013006;
-    push @todo, (15);
+    #push @todo, (15);
     push @todo, (7)   if $] eq '5.008005';
+    # 5.15 empty HV fixed with r1124
+    #push @todo, (3,4,36) if $] >= 5.015; # Assert array: Perl_hfree_next_entry hv.c:1716
+    push @todo, (16,39,44,45) if $] >= 5.015002 and !$ENV{DL_NOWARN};  # DynaLoader 5.15.2 issue
+    push @todo, (29)    if $] >= 5.015002; # B::C crash
     # 15 passes on cygwin XP, but fails on cygwin Win7
     if ($what =~ /^c(|_o[1-4])$/) {
+	push @todo, (15);
         # 14+23 fixed with 1.04_29, for 5.10 with 1.04_31
         # 15+28 fixed with 1.04_34
         # 5.6.2 CORE: 8,15,16,22. 16 fixed with 1.04_24, 8 with 1.04_25
@@ -752,29 +763,36 @@ sub todo_tests_default {
         # push @todo, (39)   if $] > 5.007 and $] < 5.009;
         # fixed with 1.30
         # push @todo, (21)   if $] > 5.011 and $] < 5.013;
-        push @todo, (29)   if $] > 5.009 and $] < 5.012;
-        push @todo, (28,48) if $what =~ /c_o[34]/;
-        push @todo, (21)   if $] > 5.011 and $] <= 5.013006;
+        push @todo, (29)    if $] > 5.009 and $] < 5.012;
+        push @todo, (48)    if $what eq 'c_o4' and $] < 5.010;
+        # push @todo, (28,48) if $what =~ /c_o[34]/  and $] < 5.014;
+        push @todo, (21)    if $] > 5.011 and $] <= 5.013006;
         #push @todo, (25)   if $] =~ /5\.012/ and $DEBUGGING and $ITHREADS; # linux only
         # c.t fixed with 1.30
-        push @todo, (16,29,44,45,49) if $] > 5.013 and !$DEBUGGING and !$ITHREADS;
-        push @todo, (10,12,16) if $what =~ /c_o[234]/ and $] >= 5.010;
-        push @todo, (11)    if $what =~ /c_o[1234]/ and $] < 5.010;
-        push @todo, (44,45) if $what =~ /c_o[1234]/;
-        push @todo, (50)    if $what =~ /c_o[234]/;
+        # push @todo, (16,44,45) if $] > 5.013 and !$DEBUGGING and !$ITHREADS;
+        # push @todo, (10,12) if $what =~ /c_o[234]/ and $] >= 5.010 and $] < 5.015;
+	# fixed with 1.35
+        # push @todo, (11)    if $what =~ /c_o[1234]/ and $] < 5.010;
+        push @todo, (44,45) if $] < 5.009;
+        push @todo, (29,44,45) if $what =~ /c_o[234]/;
+	# @ISA issue 64
+        push @todo, (50)    if $what eq 'c_o4'; 
+        push @todo, (10)    if $what =~ /c_o[234]/ and $] >= 5.010;
+        push @todo, (34)    if $what =~ /c_o[34]/  and $] > 5.011 and $] <= 5.013;
         push @todo, (19)    if $what eq 'c_o2' and $ITHREADS;
+        push @todo, (11)    if $what =~ /c_o[1234]/ and $] < 5.009 and !$ITHREADS;
 	push @todo, (10,12,19,25) if $what eq 'c_o4';
     } elsif ($what =~ /^cc/) {
         # 8,11,14..16,18..19 fail on 5.00505 + 5.6, old core failures (max 20)
         # on cygwin 29 passes
+        push @todo, (15,21,30,50); # fixed 44 -nt
 	push @todo, (3,16)  if $] eq '5.008005';
-        push @todo, (35); # fixed 44 -nt
-        push @todo, (21,30); #5.8.9
         push @todo, (44)    if $ITHREADS or $] < 5.012;
         #push @todo, (44)   if !$ITHREADS and $] >= 5.012;
-        push @todo, (105)   if $what =~ /^cc(_o1)?/ or ($] > 5.008005 and $] < 5.010);
+        push @todo, (105)   if $] > 5.008005 and $] < 5.010;
         push @todo, (10,16) if $what eq 'cc_o2';
         push @todo, (27)    if $] < 5.007 and $what eq 'cc_o2';
+        push @todo, (45)    if $] < 5.007;
         push @todo, (104)   if $] < 5.007; # leaveloop, no cxstack
         push @todo, (11,45,103,105) if $] > 5.007 and $] < 5.009;
         push @todo, (29)    if $] < 5.008006 or $] > 5.013;
@@ -785,16 +803,15 @@ sub todo_tests_default {
         #push @todo, (3,4,27,42,43) if $] >= 5.011004 and $ITHREADS;
         push @todo, (26)    if $what =~ /^cc_o[12]/;
         push @todo, (27)    if $] < 5.010 and $what eq 'cc_o2';
-        push @todo, (15)    if $] > 5.011 and $] < 5.013;
+        push @todo, (105)   if $] >= 5.010;
         push @todo, (25)    if $] >= 5.011004 and $DEBUGGING and $ITHREADS;
         push @todo, (3,4)   if $] >= 5.011004 and $ITHREADS;
         push @todo, (103)   if $] >= 5.012 and $ITHREADS;
-        #push @todo, (16)    if $] >= 5.013009;
+        #push @todo, (49)    if $] >= 5.013009 and $] < 5.015 and !$ITHREADS; # fixed with r1142
     }
     push @todo, (48)   if $] > 5.007 and $] < 5.009 and $^O =~ /MSWin32|cygwin/i;
     push @todo, (25)   if $] eq "5.010001" and !$DEBUGGING and $ITHREADS;
     push @todo, (25)   if $] >= 5.010 and $] < 5.012 and !$ITHREADS;
-    push @todo, (3,4,36) if $] >= 5.015;
     #push @todo, (32)  if $] >= 5.011003;
     return @todo;
 }
